======================
Zun Installation Guide
======================

.. toctree::

   overview.rst
   get_started.rst
   controller-install.rst
   compute-install.rst
   verify.rst
   launch-container.rst
   next-steps.rst

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial <https://docs.openstack.org/install-guide/>`_.
